@@ -22,26 +22,29 @@ using Gtk;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Clients.Classical.Dialogs
 {
 	public class PreferencesDialog : BuilderDialog
 	{
-		[GtkBeans.Builder.Object] Gtk.SpinButton prefspinbutton;
-		[GtkBeans.Builder.Object] Gtk.SpinButton maxstoredspinbutton;
-		[GtkBeans.Builder.Object] Gtk.SpinButton minplayedspinbutton;
-		[GtkBeans.Builder.Object] Gtk.CheckButton prefcheckbutton;
-		[GtkBeans.Builder.Object] Gtk.CheckButton colorblindcheckbutton;
-		[GtkBeans.Builder.Object] Gtk.RadioButton rb_easy;
-		[GtkBeans.Builder.Object] Gtk.RadioButton rb_medium;
-		[GtkBeans.Builder.Object] Gtk.RadioButton rb_master;
-		[GtkBeans.Builder.Object] Gtk.ComboBox themes_combobox;
-		[GtkBeans.Builder.Object] Gtk.CheckButton english_checkbutton;
+		[Builder.Object] Gtk.SpinButton prefspinbutton;
+		[Builder.Object] Gtk.SpinButton maxstoredspinbutton;
+		[Builder.Object] Gtk.SpinButton minplayedspinbutton;
+		[Builder.Object] Gtk.CheckButton prefcheckbutton;
+		[Builder.Object] Gtk.CheckButton colorblindcheckbutton;
+		[Builder.Object] Gtk.RadioButton rb_easy;
+		[Builder.Object] Gtk.RadioButton rb_medium;
+		[Builder.Object] Gtk.RadioButton rb_master;
+		[Builder.Object] Gtk.ComboBox themes_combobox;
+		[Builder.Object] Gtk.CheckButton englishcheckbutton;
+		[Builder.Object] Gtk.CheckButton loadextensionscheckbutton;
+		[Builder.Object] Gtk.CheckButton usesoundscheckbutton;
 
 		const int COLUMN_VALUE = 1;
 		PlayerHistory history;
 
-		public PreferencesDialog (PlayerHistory history) : base ("PreferencesDialog.ui", "preferences")
+		public PreferencesDialog (ITranslations translations, PlayerHistory history) : base (translations, "PreferencesDialog.ui", "preferences")
 		{
 			this.history = history;
 			prefspinbutton.Value = Preferences.Get <int> (Preferences.MemQuestionTimeKey);
@@ -49,7 +52,9 @@ namespace gbrainy.Clients.Classical.Dialogs
 			maxstoredspinbutton.Value = Preferences.Get <int> (Preferences.MaxStoredGamesKey);
 			minplayedspinbutton.Value = Preferences.Get <int> (Preferences.MinPlayedGamesKey);
 			colorblindcheckbutton.Active = Preferences.Get <bool> (Preferences.ColorBlindKey);
-			english_checkbutton.Active = Preferences.Get <bool> (Preferences.EnglishKey);
+			englishcheckbutton.Active = Preferences.Get <bool> (Preferences.EnglishKey);
+			loadextensionscheckbutton.Active = Preferences.Get <bool> (Preferences.LoadPlugginsKey);
+			usesoundscheckbutton.Active = Preferences.Get <bool> (Preferences.SoundsKey);
 
 			switch ((GameDifficulty) Preferences.Get <int> (Preferences.DifficultyKey)) {
 			case GameDifficulty.Easy:
@@ -86,6 +91,10 @@ namespace gbrainy.Clients.Classical.Dialogs
 				}
 				more = store.IterNext (ref iter);
 			}
+
+			#if !MONO_ADDINS
+				loadextensionscheckbutton.Visible = false;
+			#endif
 		}
 
 		private GameDifficulty Difficulty {
@@ -124,7 +133,9 @@ namespace gbrainy.Clients.Classical.Dialogs
 			Preferences.Set <int>  (Preferences.MaxStoredGamesKey, (int) maxstoredspinbutton.Value);
 			Preferences.Set <int>  (Preferences.MinPlayedGamesKey, (int) minplayedspinbutton.Value);
 			Preferences.Set <bool> (Preferences.ColorBlindKey, colorblindcheckbutton.Active);
-			Preferences.Set <bool> (Preferences.EnglishKey, english_checkbutton.Active);
+			Preferences.Set <bool> (Preferences.EnglishKey, englishcheckbutton.Active);
+			Preferences.Set <bool> (Preferences.LoadPlugginsKey, loadextensionscheckbutton.Active);
+			Preferences.Set <bool> (Preferences.SoundsKey, usesoundscheckbutton.Active);
 
 			TreeIter iter;
 			themes_combobox.GetActiveIter (out iter);
@@ -136,7 +147,7 @@ namespace gbrainy.Clients.Classical.Dialogs
 			Preferences.Save ();
 		}
 
-		static public void ComboBoxCellFunc (CellLayout cell_layout, CellRenderer cell, TreeModel tree_model, TreeIter iter)
+		static public void ComboBoxCellFunc (ICellLayout cell_layout, CellRenderer cell, ITreeModel tree_model, TreeIter iter)
 		{
 			string name = (string)tree_model.GetValue (iter, 0);
 			(cell as CellRendererText).Text = name;
