@@ -27,6 +27,7 @@ using System.Reflection;
 using gbrainy.Core.Main;
 using gbrainy.Core.Platform;
 using gbrainy.Core.Services;
+using gbrainy.Core.Libraries;
 using gbrainy.Clients.Classical.Dialogs;
 using gbrainy.Clients.Classical.Widgets;
 
@@ -39,46 +40,47 @@ namespace gbrainy.Clients.Classical
 {
 	public class GtkClient
 	{
-		[GtkBeans.Builder.Object("gbrainy")] Gtk.Window app_window;
-		[GtkBeans.Builder.Object] Gtk.CheckMenuItem showtoolbar_menuitem;
-		[GtkBeans.Builder.Object] Box drawing_vbox;
-		[GtkBeans.Builder.Object] Gtk.HBox main_hbox;
-		[GtkBeans.Builder.Object] Gtk.VBox framework_vbox;
-		[GtkBeans.Builder.Object] Gtk.Entry answer_entry;
-		[GtkBeans.Builder.Object] Gtk.Button answer_button;
-		[GtkBeans.Builder.Object] Gtk.Label answer_label;
-		[GtkBeans.Builder.Object] Gtk.Button tip_button;
-		[GtkBeans.Builder.Object] Gtk.Button next_button;
-		[GtkBeans.Builder.Object] Gtk.Statusbar statusbar;
-		[GtkBeans.Builder.Object] Gtk.MenuBar menubar;
-		[GtkBeans.Builder.Object] Gtk.MenuItem pause_menuitem;
-		[GtkBeans.Builder.Object] Gtk.MenuItem finish_menuitem;
-		[GtkBeans.Builder.Object] Gtk.MenuItem newgame_menuitem;
-		[GtkBeans.Builder.Object] Gtk.MenuItem allgames_menuitem;
-		[GtkBeans.Builder.Object] Gtk.MenuItem logic_menuitem;
-		[GtkBeans.Builder.Object] Gtk.MenuItem calculation_menuitem;
-		[GtkBeans.Builder.Object] Gtk.MenuItem memory_menuitem;
-		[GtkBeans.Builder.Object] Gtk.MenuItem verbal_menuitem;
-		[GtkBeans.Builder.Object] Gtk.MenuItem extensions_menuitem;
-		[GtkBeans.Builder.Object] Gtk.RadioMenuItem vertical_radiomenuitem;
-		[GtkBeans.Builder.Object] Gtk.RadioMenuItem horizontal_radiomenuitem;
-		[GtkBeans.Builder.Object] Gtk.MenuItem toolbar_orientation_menuitem;
+		[Builder.Object("gbrainy")] Gtk.Window app_window;
+		[Builder.Object] Gtk.CheckMenuItem showtoolbar_menuitem;
+		[Builder.Object] Box drawing_vbox;
+		[Builder.Object] Gtk.Box main_hbox;
+		[Builder.Object] Gtk.Box framework_vbox;
+		[Builder.Object] Gtk.Entry answer_entry;
+		[Builder.Object] Gtk.Button answer_button;
+		[Builder.Object] Gtk.Label answer_label;
+		[Builder.Object] Gtk.Button tip_button;
+		[Builder.Object] Gtk.Button next_button;
+		[Builder.Object] Gtk.Statusbar statusbar;
+		[Builder.Object] Gtk.MenuBar menubar;
+		[Builder.Object] Gtk.MenuItem pause_menuitem;
+		[Builder.Object] Gtk.MenuItem finish_menuitem;
+		[Builder.Object] Gtk.MenuItem newgame_menuitem;
+		[Builder.Object] Gtk.MenuItem allgames_menuitem;
+		[Builder.Object] Gtk.MenuItem logic_menuitem;
+		[Builder.Object] Gtk.MenuItem calculation_menuitem;
+		[Builder.Object] Gtk.MenuItem memory_menuitem;
+		[Builder.Object] Gtk.MenuItem verbal_menuitem;
+		[Builder.Object] Gtk.MenuItem extensions_menuitem;
+		[Builder.Object] Gtk.RadioMenuItem vertical_radiomenuitem;
+		[Builder.Object] Gtk.RadioMenuItem horizontal_radiomenuitem;
+		[Builder.Object] Gtk.MenuItem toolbar_orientation_menuitem;
 
 		Widgets.Toolbar toolbar;
 
 		GameDrawingArea drawing_area;
 		GameSession session;
-		bool low_res;
 		bool full_screen;
 		GameSession.Types initial_session;
+		static bool pluggins_loaded;
 
 		public readonly int MIN_TRANSLATION = 80;
 
-		public GtkClient ()
+		public GtkClient (ITranslations translations)
 		{
+			Translations = translations;
 			if (Preferences.Get <bool> (Preferences.EnglishKey) == false)
 			{
-				Catalog.Init ("gbrainy", Defines.GNOME_LOCALE_DIR);
+				translations.Init ("gbrainy", Defines.GNOME_LOCALE_DIR);
 			}
 
 			Unix.FixLocaleInfo ();
@@ -93,13 +95,16 @@ namespace gbrainy.Clients.Classical
 			set { initial_session = value; }
 		}
 
+		ITranslations Translations {get; set;}
+
 		public void Initialize ()
 		{
-			session = new GameSession ();
+			session = new GameSession (Translations);
+			
 			GameManagerPreload (session.GameManager);
-			Console.WriteLine (session.GameManager.GetGamesSummary ());
+			Console.WriteLine (session.GameManager.GetGamesSummary (Translations));
 
-			session.GameManager.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
+			session.PlayList.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
 			session.DrawRequest += SessionDrawRequest;
 			session.UpdateUIElement += SessionUpdateUIElement;
 			session.SynchronizingObject = new GtkSynchronize ();
@@ -113,17 +118,22 @@ namespace gbrainy.Clients.Classical
 			gm.LoadAssemblyGames (Defines.GAME_ASSEMBLY);
 			gm.LoadVerbalAnalogies (System.IO.Path.Combine (Defines.DATA_DIR, Defines.VERBAL_ANALOGIES));
 			gm.LoadGamesFromXml (System.IO.Path.Combine (Defines.DATA_DIR, Defines.GAMES_FILE));
-			gm.LoadPlugins ();
+
+			if (Preferences.Get <bool> (Preferences.LoadPlugginsKey))
+			{			
+				gm.LoadPlugins ();
+				pluggins_loaded = true;
+			}
 		}
 
 		void BuildUI ()
 		{
 			bool show_toolbar;
 
-			GtkBeans.Builder builder = new GtkBeans.Builder ("gbrainy.ui");
+			Builder builder = new Builder ("gbrainy.ui");
 			builder.Autoconnect (this);
 
-			show_toolbar = Preferences.Get <bool> (Preferences.ToolbarShowKey) == true && low_res == false;
+			show_toolbar = Preferences.Get <bool> (Preferences.ToolbarShowKey) == true;
 
 			// Toolbar creation
 			toolbar = new Widgets.Toolbar (main_hbox, framework_vbox);
@@ -138,16 +148,10 @@ namespace gbrainy.Clients.Classical
 
 			drawing_area = new GameDrawingArea ();
 			drawing_area.Drawable = session;
+                        drawing_area.Vexpand = true;
+                        drawing_area.SetSizeRequest (drawing_vbox.WidthRequest, drawing_vbox.HeightRequest);
 			GameSensitiveUI ();
 
-			// For low resolutions, hide the toolbar and made the drawing area smaller
-			if (drawing_area.Screen.Width> 0 && drawing_area.Screen.Height > 0) {
-				if (drawing_area.Screen.Height < 700) {
-					drawing_vbox.HeightRequest = 350;
-					low_res = true;
-				}
-			}
-
 			EventBox eb = new EventBox (); // Provides a window for drawing area windowless widget
 
 			eb.Events = Gdk.EventMask.PointerMotionMask;
@@ -158,7 +162,7 @@ namespace gbrainy.Clients.Classical
 			eb.MotionNotifyEvent += OnMouseMotionEvent;
 			eb.ButtonPressEvent += OnHandleButtonPress;
 
-			show_toolbar = Preferences.Get <bool> (Preferences.ToolbarShowKey) == true && low_res == false;
+			show_toolbar = Preferences.Get <bool> (Preferences.ToolbarShowKey) == true;
 
 			// We only disable the Arrow if we are going to show the toolbar.
 			// It has an impact on the total window width size even if we do not show it
@@ -190,7 +194,11 @@ namespace gbrainy.Clients.Classical
 
 		#if MONO_ADDINS
 			extensions_menuitem.Activated += delegate (object sender, EventArgs ar) 
-			{ 
+			{
+				if (pluggins_loaded == false)
+				{			
+					session.GameManager.LoadPlugins ();
+				}
 				Mono.Addins.Gui.AddinManagerWindow.Run (app_window);
 				GameManagerPreload (session.GameManager);
 				CustomGameDialog.Clear ();
@@ -419,9 +427,13 @@ namespace gbrainy.Clients.Classical
 
 			correct = session.ScoreGame (answer_entry.Text);
 			if (correct)
-				answer = Catalog.GetString ("Congratulations.");
+			{
+				answer = Translations.GetString ("Congratulations.");
+			}
 			else
-				answer = Catalog.GetString ("Incorrect answer.");
+			{
+				answer = Translations.GetString ("Incorrect answer.");
+			}			
 
 			session.EnableTimer = false;
 			answer_entry.Text = String.Empty;
@@ -434,6 +446,11 @@ namespace gbrainy.Clients.Classical
 			ActiveInputControls (true);
 			next_button.GrabFocus ();
 			drawing_area.QueueDraw ();
+
+			if (Preferences.Get <bool> (Preferences.SoundsKey))
+			{
+				Unix.PlaySound(app_window.Handle, System.IO.Path.Combine(Defines.DATA_DIR, correct ? "right.oga" : "wrong.oga"));
+			}
 		}
 
 		void OnQuit (object sender, EventArgs args)
@@ -469,25 +486,25 @@ namespace gbrainy.Clients.Classical
 		void OnNewGame (GameSession.Types type)
 		{
 			// If the translation is lower than MIN_TRANSLATION explain that running the English version is an option
-			if (ShowTranslationWarning ())
-				Translations ();
+			if (ShouldShowTranslationWarning ())
+				ShowTranslationWarning ();
 
 			session.Type = type;
 			session.New ();
 			GetNextGame ();
 			GameSensitiveUI ();
-			UpdateSolution (Catalog.GetString ("Once you have an answer type it in the \"Answer:\" entry box and press the \"OK\" button."),
+			UpdateSolution (Translations.GetString ("Once you have an answer type it in the \"Answer:\" entry box and press the \"OK\" button."),
 				GameDrawingArea.SolutionType.Tip);
 			UpdateStatusBar ();
 		}
 
-		public bool ShowTranslationWarning ()
+		public bool ShouldShowTranslationWarning ()
 		{
 			// Notify the user once per version only
 			if (String.Compare (Preferences.Get <string> (Preferences.EnglishVersionKey), Defines.VERSION, 0) == 0)
 				return false;
 
-			int percentage = ServiceLocator.Instance.GetService <ITranslations> ().TranslationPercentage;
+			int percentage = Translations.TranslationPercentage;
 			if (percentage > 0 && percentage < MIN_TRANSLATION)
 			{
 				Preferences.Set <string> (Preferences.EnglishVersionKey, Defines.VERSION);
@@ -498,7 +515,7 @@ namespace gbrainy.Clients.Classical
 			return false;
 		}
 
-		void Translations ()
+		void ShowTranslationWarning ()
 		{		
 			HigMessageDialog dlg;
 	
@@ -506,8 +523,8 @@ namespace gbrainy.Clients.Classical
 				Gtk.DialogFlags.DestroyWithParent,
 				Gtk.MessageType.Warning,
 				Gtk.ButtonsType.Ok,
-				Catalog.GetString ("The level of translation of gbrainy for your language is low."),
-				Catalog.GetString ("You may be exposed to partially translated games making it more difficult to play. If you prefer to play in English, there is an option for doing so in gbrainy's Preferences."));
+				Translations.GetString ("The level of translation of gbrainy for your language is low."),
+				Translations.GetString ("You may be exposed to partially translated games making it more difficult to play. If you prefer to play in English, there is an option for doing so in gbrainy's Preferences."));
 		
 			try {
 	 			dlg.Run ();
@@ -535,7 +552,7 @@ namespace gbrainy.Clients.Classical
 		{
 			PdfExportDialog pdf;
 
-			pdf = new PdfExportDialog ();
+			pdf = new PdfExportDialog (session.GameManager, Translations);
 			pdf.Run ();
 			pdf.Destroy ();
 		}
@@ -544,10 +561,10 @@ namespace gbrainy.Clients.Classical
 		{
 			PreferencesDialog dialog;
 
-			dialog = new PreferencesDialog (session.PlayerHistory);
+			dialog = new PreferencesDialog (Translations, session.PlayerHistory);
 			if ((Gtk.ResponseType) dialog.Run () == ResponseType.Ok) {
 				session.Difficulty = (GameDifficulty) Preferences.Get <int> (Preferences.DifficultyKey);
-				session.GameManager.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
+				session.PlayList.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
 
 				if (dialog.NewThemeSet == true)
 					drawing_area.ReloadBackground ();
@@ -559,7 +576,7 @@ namespace gbrainy.Clients.Classical
 		{
 			CustomGameDialog dialog;
 
-			dialog = new CustomGameDialog (session.GameManager);
+			dialog = new CustomGameDialog (Translations, session);
 			dialog.Run ();
 			dialog.Destroy ();
 
@@ -603,12 +620,12 @@ namespace gbrainy.Clients.Classical
 			if (pause) {
 				drawing_area.Paused = false;
 				toolbar.PauseButton.StockId = "pause";
-				toolbar.PauseButton.Label = Catalog.GetString ("Pause");
+				toolbar.PauseButton.Label = Translations.GetString ("Pause");
 				ActiveInputControls (true);
 			} else {
 				drawing_area.Paused = true;
 				toolbar.PauseButton.StockId = "resume";
-				toolbar.PauseButton.Label = Catalog.GetString ("Resume");
+				toolbar.PauseButton.Label = Translations.GetString ("Resume");
 				ActiveInputControls (false);
 			}
 			UpdateStatusBar ();
@@ -685,7 +702,7 @@ namespace gbrainy.Clients.Classical
 		{
 			PlayerHistoryDialog dialog;
 
-			dialog = new PlayerHistoryDialog (session.PlayerHistory);
+			dialog = new PlayerHistoryDialog (Translations, session.PlayerHistory);
 			dialog.Run ();
 			dialog.Destroy ();
 		}
@@ -704,7 +721,7 @@ namespace gbrainy.Clients.Classical
 
 		void OnExtending (object sender, EventArgs args)
 		{
-			Process.Start ("http://live.gnome.org/gbrainy/Extending");
+			Process.Start ("https://wiki.gnome.org/Apps/gbrainy/Extending");
 		}
 
 		static void InitCoreLibraries ()
@@ -732,13 +749,14 @@ namespace gbrainy.Clients.Classical
 			}
 
 			DateTime start_time = DateTime.Now;
+			ITranslations translations = new TranslationsCatalog ();
 
 			InitCoreLibraries ();
 
-			GtkClient app = new GtkClient ();
+			GtkClient app = new GtkClient (translations);
 			CommandLine.Version ();
 
-			CommandLine line = new CommandLine (args);
+			CommandLine line = new CommandLine (translations, args);
 			line.Parse ();
 
 			if (line.Continue == false)
@@ -748,9 +766,9 @@ namespace gbrainy.Clients.Classical
 
 			app.Initialize ();
 			// Set RandomOrder before setting the custom list then it has effect of custom games
-			app.Session.GameManager.RandomOrder = line.RandomOrder;
+			app.Session.PlayList.RandomOrder = line.RandomOrder;
 			if (line.PlayList.Length > 0) {
-				app.Session.GameManager.PlayList = line.PlayList;
+				app.Session.PlayList.PlayList = line.PlayList;
 				app.InitialSessionType = GameSession.Types.Custom;
 			}
 			app.ProcessDefaults ();
