@@ -17,7 +17,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
@@ -26,8 +25,6 @@ namespace gbrainy.Games.Logic
 {
 	public class PuzzleCountCircles : Game
 	{
-		private const double figure_size = 0.3;
-		private const double radian = Math.PI / 180;
 		private int n_circles;
 
 		class ItemCircle
@@ -45,15 +42,15 @@ namespace gbrainy.Games.Logic
 		ItemCircle[] circles;
 
 		public override string Name {
-			get {return Catalog.GetString ("Count circles");}
+			get {return Translations.GetString ("Count circles");}
 		}
 
 		public override string Question {
-			get {return Catalog.GetString ("How many circles do you count?");} 
+			get {return Translations.GetString ("How many circles do you count?");} 
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("It is an easy exercise if you systematically count the circles.");}
+			get { return Translations.GetString ("It is an easy exercise if you systematically count the circles.");}
 		}
 
 		protected override void Initialize ()
@@ -84,7 +81,7 @@ namespace gbrainy.Games.Logic
 				circles[i] = new ItemCircle (x, y, rad);
 			}
 
-			right_answer = n_circles.ToString ();
+			Answer.Correct = n_circles.ToString ();
 		}	
 
 
